### academic inequality 1 ###

#this project is about understanding the relationship between institutional affiliation and publication
#in four prestige journals in the humanities.

#meta table
a<-read.csv("journals_masterlist 2.csv")

#number of articles
nlevels(a$ID)

#number of authors
nlevels(a$author)

#number of PhD Institutions
nlevels(a$PhD)-1 #removes N/A as level

#number of author institutions
nlevels(a$Institutional_Affiliation)-1 #removes N/A as level

#division of articles by journal
table(a$journaltitle)
#as %
table(a$journaltitle)/nlevels(a$ID)

#date range of all data
hist(a$pub.year)
summary(a$pub.year)

#of each journal
min(a$pub.year[a$journaltitle == "Critical Inquiry"])
max(a$pub.year[a$journaltitle == "Critical Inquiry"])
min(a$pub.year[a$journaltitle == "New Literary History"])
max(a$pub.year[a$journaltitle == "New Literary History"])
min(a$pub.year[a$journaltitle == "PMLA"])
max(a$pub.year[a$journaltitle == "PMLA"])
min(a$pub.year[a$journaltitle == "Representations"])
max(a$pub.year[a$journaltitle == "Representations"])

### PhD institutions ###
phd.rank<-data.frame(sort(table(a$PhD), decreasing = T))
#remove N/A
phd.rank<-phd.rank[!phd.rank$Var1 == "N/A",]

#calculate Gini co-efficient for all data
Gini(phd.rank$Freq)

#what % of articles are accounted for by the top 25% of PhD granting institutions?
top.25per<-round(.25*nrow(phd.rank))
sum(phd.rank$Freq[1:top.25per])/sum(phd.rank$Freq)

#what % of articles are accounted for by the top 20% of PhD granting institutions?
top.20per<-round(.2*nrow(phd.rank))
sum(phd.rank$Freq[1:top.20per])/sum(phd.rank$Freq)

#what % of articles are accounted for by the top 10 PhD granting institutions?
sum(phd.rank$Freq[1:10])/sum(phd.rank$Freq)

#what % of articles are accounted for by the top 2?
sum(phd.rank$Freq[1:2])/sum(phd.rank$Freq)

#were Yale/Harvard leading institutions for each journal?
data.frame(sort(table(a$PhD[a$journaltitle == "Critical Inquiry"]), decreasing = T))[1:2,]
data.frame(sort(table(a$PhD[a$journaltitle == "New Literary History"]), decreasing = T))[1:2,]
data.frame(sort(table(a$PhD[a$journaltitle == "PMLA"]), decreasing = T))[1:2,]
data.frame(sort(table(a$PhD[a$journaltitle == "Representations"]), decreasing = T))[1:3,]

#test pre and post 1990
a.post90<-a[a$pub.year > 1989,]
phd.rank.post90<-data.frame(sort(table(a.post90$PhD), decreasing = T))
phd.rank.post90<-phd.rank.post90[!phd.rank.post90$Var1 == "N/A",]

a.pre90<-a[a$pub.year < 1990,]
phd.rank.pre90<-data.frame(sort(table(a.pre90$PhD), decreasing = T))
phd.rank.pre90<-phd.rank.pre90[!phd.rank.pre90$Var1 == "N/A",]

#Gini coefficient
Gini(phd.rank.post90$Freq)
Gini(phd.rank.pre90$Freq)
#number of articles
nlevels(factor(a.post90$ID))
#number of authors
nlevels(factor(a.post90$author))
#number of PhD Institutions
nlevels(factor(a.post90$PhD))
#number of author institutions
nlevels(factor(a.post90$Institutional_Affiliation))
#top 10
sum(phd.rank.post90$Freq[1:10])/sum(phd.rank.post90$Freq)
#top 2
sum(phd.rank.post90$Freq[1:2])/sum(phd.rank.post90$Freq)

### Author Institutions ###
author.rank<-data.frame(sort(table(a$Institutional_Affiliation), decreasing = T))
author.rank<-author.rank[!author.rank$Var1 == "N/A",]

#Gini co-efficient on all data
Gini(author.rank$Freq)

#what % of articles are accounted for by the top 25% of author institutions?
auth.top.25per<-round(.25*nrow(author.rank))
sum(author.rank$Freq[1:auth.top.25per])/sum(author.rank$Freq)


#what % of articles are accounted for by the top 20% of author institutions?
auth.top.20per<-round(.2*nrow(author.rank))
sum(author.rank$Freq[1:auth.top.20per])/sum(author.rank$Freq)

#what % of articles are accounted for by the top 10 author institutions?
sum(author.rank$Freq[1:10])/sum(author.rank$Freq)

#what % of articles are accounted for by the top 2?
sum(author.rank$Freq[1:2])/sum(author.rank$Freq)

#Produce Table 1
col1<-phd.rank[1:20,1:2]
col2<-author.rank[1:20,1:2]
table1<-cbind(col1, col2)
colnames(table1)<-c("PhD Institution", "No. Articles", "Author Institution", "No. Articles")
write.csv(table1, file="Table1_New.csv", row.names = F)

### Heterogeneity Scores ###

#first calculate the heterogeneity score for a given year per journal
#heterogeneity = # institutions / # articles per year
library(ineq)
het.df<-NULL
for (i in 1:nlevels(a$journaltitle)){
  sub<-a[a$journaltitle == levels(a$journaltitle)[i],]
  for (j in 1:nlevels(as.factor(sub$pub.year))){
    sub1<-sub[sub$pub.year == levels(as.factor(sub$pub.year))[j],]
    het.score.author<-nlevels(factor(sub1$Institutional_Affiliation))/nrow(sub1)
    het.score.phd<-nlevels(factor(sub1$PhD))/nrow(sub1)
    hhi.author<-1-Herfindahl(sort(table(as.character(sub1$Institutional_Affiliation)), decreasing = T))
    hhi.phd<-1-Herfindahl(sort(table(as.character(sub1$PhD)), decreasing = T))
    journal<-as.character(sub$journaltitle[1])
    no.articles<-nrow(sub1)
    year<-sub1$pub.year[1]
    temp.df<-data.frame(journal, year, het.score.author, het.score.phd, hhi.author, hhi.phd, no.articles)
    het.df<-rbind(het.df, temp.df)
  }
}

## NEW CODE ##
#take random samples for each journal and calculate population mean
het2.df<-NULL
for (i in 1:nlevels(a$journaltitle)){
  print(i)
  sub<-a[a$journaltitle == levels(a$journaltitle)[i],]
  for (j in 1:1000){
    sub1<-sub[sample(nrow(sub),100),]
    het.score.author<-nlevels(factor(sub1$Institutional_Affiliation))/nlevels(factor(sub1$ID))
    het.score.phd<-nlevels(factor(sub1$PhD))/nlevels(factor(sub1$ID))
    hhi.author<-1-Herfindahl(sort(table(as.character(sub1$Institutional_Affiliation)), decreasing = T))
    hhi.phd<-1-Herfindahl(sort(table(as.character(sub1$PhD)), decreasing = T))
    gini.author<-1-Gini(sort(table(as.character(sub1$Institutional_Affiliation)), decreasing = T))
    gini.phd<-1-Gini(sort(table(as.character(sub1$PhD)), decreasing = T))
    journal<-as.character(sub$journaltitle[1])
    #no.articles<-nrow(sub1)
    #year<-sub1$pub.year[1]
    temp.df<-data.frame(journal, het.score.author, het.score.phd, hhi.author, hhi.phd, gini.author, gini.phd)
    het2.df<-rbind(het2.df, temp.df)
  }
}

#plot
all1<-data.frame(het2.df[,1:3], c("Author"))
all1<-all1[,-3]
all2<-data.frame(het2.df[,-2], c("PhD"))
remove<-c(3,4,5,6)
all2<-all2[,-remove]
colnames(all1)<-c("Journal", "Heterogeneity", "Category")
colnames(all2)<-c("Journal", "Heterogeneity", "Category")
all3<-rbind(all1, all2)

#calculate mean for each journal
mean(all3$Heterogeneity[all3$Journal == "PMLA" & all3$Category == "Author"])
mean(all3$Heterogeneity[all3$Journal == "New Literary History" & all3$Category == "Author"])
mean(all3$Heterogeneity[all3$Journal == "Critical Inquiry" & all3$Category == "Author"])
mean(all3$Heterogeneity[all3$Journal == "Representations" & all3$Category == "Author"])

#analysis of variance test
sub<-all3[all3$Category == "PhD",]
summary(aov(sub$Heterogeneity ~ sub$Journal))

#compare PhD average to Author average
t.test(all3$Heterogeneity[all3$Category=="PhD"], all3$Heterogeneity[all3$Category=="Author"])

#make same table for HHI
all1.hhi<-data.frame(het2.df[,1:5], c("Author"))
all2.hhi<-data.frame(het2.df[,1:5], c("PhD"))
remove1<-c(2,3,5)
remove2<-c(2,3,4)
all1.hhi<-all1.hhi[,-remove1]
all2.hhi<-all2.hhi[,-remove2]
colnames(all1.hhi)<-c("Journal", "Heterogeneity", "Category")
colnames(all2.hhi)<-c("Journal", "Heterogeneity", "Category")
all3.hhi<-rbind(all1.hhi, all2.hhi)

#make same table for Gini
all1.gini<-data.frame(het2.df[,1:7], c("Author"))
all2.gini<-data.frame(het2.df[,1:7], c("PhD"))
remove1<-c(2,3,4,5,7)
remove2<-c(2,3,4,5,6)
all1.gini<-all1.gini[,-remove1]
all2.gini<-all2.gini[,-remove2]
colnames(all1.gini)<-c("Journal", "Heterogeneity", "Category")
colnames(all2.gini)<-c("Journal", "Heterogeneity", "Category")
all3.gini<-rbind(all1.gini, all2.gini)


#reorder factors by variable

#Color
ggplot(all3.gini, aes(reorder(factor(Journal), -Heterogeneity), Heterogeneity)) + #boxplot with ordered factors
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_boxplot(aes(fill = Category)) +
  scale_fill_manual(values = c("green","orange")) +
  xlab("Journals")+
  ylab("Inverse Gini Co-efficient")+
  ggtitle("Institutional Heterogeneity Across 4 Journals, 1970-2015")

#test correlation between scores
cor.test(het.df$het.score.author, het.df$hhi.author)
cor.test(het.df$het.score.phd, het.df$hhi.phd)

#test correlations with number of articles per year
#cor.test(het.df$het.score.author, het.df$no.articles)
#cor.test(het.df$hhi.author, het.df$no.articles)
cor.test(het.df$het.score.phd, het.df$no.articles)
cor.test(het.df$hhi.phd, het.df$no.articles)
#the important point is the way the scores correlate in different directions with the number of articles published
#HHI shows more diversity with more articles and assumption we do not wish to make

#median score for each journal - author
het.med.auth<-tapply(het.df$het.score.author, het.df$journal, median)
hhi.med.auth<-tapply(het.df$hhi.author, het.df$journal, median)

#median score for each journal - phd
het.med.phd<-tapply(het.df$het.score.phd, het.df$journal, median)
hhi.med.phd<-tapply(het.df$hhi.phd, het.df$journal, median)

#combine into table
het.both<-data.frame(het.med.auth, het.med.phd, hhi.med.auth, hhi.med.phd)
#write.csv(het.both, file="Table3.csv")

#anova test comparing author heterogeneity between journals
summary(aov(het.score.author ~ journal, data=het.df))

#Tukey's Range Test to compare journals to each other
library(DTK)
results = DTK.test(het2.df$het.score.author,het2.df$journal,0.05)
results
DTK.plot(results)

#wilcoxon test comparing author heterogeneity to phd heterogeneity
shapiro.test(het2.df$het.score.author)
shapiro.test(het2.df$het.score.phd)
hist(het2.df$het.score.phd)
hist(het2.df$het.score.author)
wilcox.test(het2.df$het.score.author, het.df$het.score.phd, paired=T)
median(het2.df$het.score.author)
median(het2.df$het.score.phd)

#avg. yearly heterogeneity
#here we test a variety of scores -- our heterogeneity score, gini coefficient, and HHI
het.yearly<-NULL
for (i in 1:nlevels(as.factor(a$pub.year))){
  sub<-a[a$pub.year == levels(as.factor(a$pub.year))[i],]
  #create tables
  phd.rank<-data.frame(sort(table(factor(sub$PhD)), decreasing = T))
  phd.rank<-phd.rank[phd.rank$Var1 != "N/A",]
  author.rank<-data.frame(sort(table(factor(sub$Institutional_Affiliation)), decreasing = T))
  author.rank<-author.rank[author.rank$Var1 != "N/A",]
  #calculate scores
  # heterogeneity score = # of institutions / # articles
  het.score.author<-nrow(author.rank)/nlevels(factor(sub$ID))
  het.score.phd<-nrow(phd.rank)/nlevels(factor(sub$ID))
  #gini coefficient which measures inequality of distribution between institutions and articles
  gini.phd<-1-Gini(phd.rank$Freq)
  gini.author<-1-Gini(author.rank$Freq)
  #HHI which measures concentratedness of an industry
  hhi.phd<-1-Herfindahl(phd.rank$Freq)
  hhi.author<-1-Herfindahl(author.rank$Freq)
  #tabulate
  year<-as.numeric(as.character(levels(as.factor(a$pub.year))[i]))
  no.articles<-nlevels(factor(sub$ID))
  temp.df<-data.frame(year, no.articles, het.score.author, het.score.phd, gini.phd, gini.author, hhi.phd, hhi.author)
  het.yearly<-rbind(het.yearly, temp.df)
}
het.yearly<-het.yearly[-1,]#remove pre-1970
mean(het.yearly$het.score.author)
median(het.yearly$het.score.author)
mean(het.yearly$het.score.phd)
median(het.yearly$het.score.phd)

#here again test for correlations between the scores
cor.test(het.yearly$het.score.author, het.yearly$gini.author)
cor.test(het.yearly$het.score.author, het.yearly$hhi.author)
cor.test(het.yearly$het.score.phd, het.yearly$gini.phd)
cor.test(het.yearly$het.score.phd, het.yearly$hhi.phd)

#test linear regression for author / Phd heterogeneity
#importantly here we control first for the date when all four journals come into being
#otherwise the initial period looks better/worse depending on the measure you use
het.yearly<-het.yearly[het.yearly$year > 1982,]

#author heterogeneity
inter.lm<-lm(het.yearly$het.score.author ~ het.yearly$year)
inter.lm<-lm(het.yearly$het.score.author ~ het.yearly$year+I(het.yearly$year^2))
summary(inter.lm)
plot(het.yearly$year, het.yearly$het.score.author, main = "Heterogeneity Score")
lines(het.yearly$year, predict(inter.lm), col="black")

#phd
inter.lm<-lm(het.yearly$het.score.phd ~ het.yearly$year)
inter.lm<-lm(het.yearly$het.score.phd ~ het.yearly$year+I(het.yearly$year^2))
summary(inter.lm)
plot(het.yearly$year, het.yearly$het.score.phd, main = "Heterogeneity Score")
lines(het.yearly$year, predict(inter.lm), col="black")

#choose best model
inter.lm1<-lm(het.yearly$het.score.author ~ het.yearly$year)
inter.lm2<-lm(het.yearly$het.score.author ~ het.yearly$year+I(het.yearly$year^2))
inter.lm1<-lm(het.yearly$het.score.phd ~ het.yearly$year)
inter.lm2<-lm(het.yearly$het.score.phd ~ het.yearly$year+I(het.yearly$year^2))

BIC(inter.lm1)
BIC(inter.lm2)

#author HHI
inter.lm<-lm(het.yearly$hhi.author ~ het.yearly$year)
summary(inter.lm)
plot(het.yearly$year, het.yearly$hhi.author, main = "HHI Score")
lines(het.yearly$year, predict(inter.lm), col="black")

#author post 1990
inter.lm<-lm(het.yearly$het.score.author[8:33] ~ het.yearly$year[8:33])
inter.lm<-lm(het.yearly$het.score.author[8:33] ~ het.yearly$year[8:33]+I(het.yearly$year[8:33]^2))
summary(inter.lm)
plot(het.yearly$year[8:33], het.yearly$het.score.author[8:33], main="Heterogeneity Post-1990")
lines(het.yearly$year[8:33], predict(inter.lm), col="black")

#phd
inter.lm<-lm(het.yearly$het.score.phd[8:33] ~ het.yearly$year[8:33])
summary(inter.lm)
plot(het.yearly$year[8:33], het.yearly$het.score.phd[8:33], main="Heterogeneity Post-1990")
lines(het.yearly$year[8:33], predict(inter.lm), col="black")

#author post 1990 HHI
inter.lm<-lm(het.yearly$hhi.author[8:33] ~ het.yearly$year[8:33])
summary(inter.lm)
plot(het.yearly$year[8:33], het.yearly$hhi.author[8:33], main="HHI Post-1990")
lines(het.yearly$year[8:33], predict(inter.lm), col="black")

#phd Heterogeneity
inter.lm<-lm(het.yearly$het.score.phd ~ het.yearly$year)
summary(inter.lm)
plot(het.yearly$year, het.yearly$het.score.phd, main = "Heterogeneity - Phd")
lines(het.yearly$year, predict(inter.lm), col="black")

#phd HHI
#inter.lm<-lm(het.yearly$hhi.phd ~ het.yearly$year)
#summary(inter.lm)
#plot(het.yearly$year, het.yearly$hhi.phd, main = "HHI - Phd")
#lines(het.yearly$year, predict(inter.lm), col="black")

#phd post 1990 heterogeneity
inter.lm<-lm(het.yearly$het.score.phd[17:42] ~ het.yearly$year[17:42])
summary(inter.lm)
plot(het.yearly$year[17:42], het.yearly$het.score.phd[17:42], main = "Heterogeneity - PhD Post90")
lines(het.yearly$year[17:42], predict(inter.lm), col="black")

#phd post 1990 HHI
#inter.lm<-lm(het.yearly$hhi.phd[22:46] ~ het.yearly$year[22:46])
#summary(inter.lm)
#plot(het.yearly$year[22:46], het.yearly$hhi.phd[22:46], main = "HHI - PhD Post90")
#lines(het.yearly$year[22:46], predict(inter.lm), col="black")

#correlation with program size
prog2<-read.csv("PhD_Freq_v_numberDissertations_v2.csv")
#test correlation using ranked lists
cor(prog2$no.articles, prog2$dissertations_updated, method="kendall", use="pairwise")
#how many of top 10 programs for dissertations are in top 10 for publication?
sub1<-as.character(prog2[1:10,1])
prog2<-prog2[order(-prog2$dissertations_updated),]
sub2<-as.character(prog2[1:10,1])
which(sub1 %in% sub2)

#gender analysis
#calculate yearly gender ratio
gender.df<-NULL
for (i in 1:nlevels(a$journaltitle)){
  sub<-a[a$journaltitle == levels(a$journaltitle)[i],]
  for (j in 1:nlevels(as.factor(sub$pub.year))){
    sub1<-sub[sub$pub.year == levels(as.factor(sub$pub.year))[j],]
    gend.score<-length(which(sub1$Gender == "F"))/nlevels(factor(sub1$ID))
    #gend.score<-length(which(sub1$Gender == "F"))/nrow(sub1)
    journal<-as.character(sub$journaltitle[1])
    year<-sub1$pub.year[1]
    temp.df<-data.frame(journal, year, gend.score)
    gender.df<-rbind(gender.df, temp.df)
  }
}

#which years are greater than or equal to 50%
gender.sub<-gender.df[gender.df$gend.score >= 0.5,]
gender.sub2<-gender.df[gender.df$gend.score > 0.5,]

#calculate overall average per journal
tapply(gender.df$gend.score, gender.df$journal, mean)

#overall mean yearly gender ratio
mean(gender.df$gend.score)

#calculate for post-2000
gender.2000<-gender.df[gender.df$year > 1999,]
tapply(gender.2000$gend.score, gender.2000$journal, mean)
mean(gender.2000$gend.score)

#load supplementary journals
b<-read.csv("yearly_gender.csv")

#total # articles
sum(b$total)

#avg % articles by women in supplementary data
mean(b$percent_women)

#add our 4 prestige journals
gender.2010<-gender.df[gender.df$year>2009,]
mean(gender.2010$gend.score*100)

#combine all together
g.v<-append(b$percent_women, gender.2010$gend.score*100)
mean(g.v)

#make Table 2
#gender.df1<-data.frame(tapply(b$percent_women, b$journal, mean)
#gender.df2<-data.frame(tapply(gender.2010$gend.score*100, gender.2010$journal, mean))
gender.df1<-NULL
for (i in 1:nlevels(b$journal)){
  sub<-b[b$journal == levels(b$journal)[i],]
  perc.women<-sum(sub$F)/sum(sub$total)
  temp<-data.frame(levels(b$journal)[i], perc.women)
  gender.df1<-rbind(gender.df1, temp)
}
gender.df1$perc.women<-gender.df1$perc.women*100
a.sub<-a[a$pub.year > 2009,]
gender.df2<-NULL
for (i in 1:nlevels(a.sub$journaltitle)){
  sub<-a.sub[a.sub$journaltitle == levels(a.sub$journaltitle)[i],]
  perc.women<-length(which(sub$Gender=="F"))/nrow(sub)
  temp<-data.frame(levels(a.sub$journaltitle)[i], perc.women)
  gender.df2<-rbind(gender.df2, temp)
}
gender.df2$perc.women<-gender.df2$perc.women*100
colnames(gender.df1)<-c("Journal", "% Women")
colnames(gender.df2)<-c("Journal", "% Women")
gender.all<-rbind(gender.df1, gender.df2)
#gender.all<-gender.all[order(-gender.all$`% Female Authors`),]
write.csv(gender.all, file="Table2_New.csv", row.names=F)

#VIDA counts
c<-read.csv("Vida_2014.csv")
sum(c$f)/sum(c$f+c$m)

### Figures ###
library(ggplot2)
#Fig.1 = PHD & Author Distribution
#Fig.2 = Lorenz Curve
#Fig.3 = Heterogeneity Scores
#Fig.4 = Heterogeneity Over Time
#Fig.5 = Gender Balance Over Time
  
  
#Fig. 1
all1<-data.frame(phd.rank$Freq[1:200], c("PhD"), seq(1:200))
all2<-data.frame(author.rank$Freq[1:200], c("Author"), seq(1:200))
colnames(all1)<-c("Frequency", "Category", "Index")
colnames(all2)<-c("Frequency", "Category", "Index")
all3<-rbind(all1, all2)

#BW
p1<-ggplot(all3, aes(x=Index, y=Frequency, width=1)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_bar(stat="identity", position="identity") +
  xlab("Universities") +
  ylab("No. Publications") +
  ggtitle("Articles by Institutional Affiliation")

p1 + facet_grid(. ~ Category) 

#Color
p1<-ggplot(all3, aes(x=Index, y=Frequency, width=1, fill=Category)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_bar(stat="identity", position="identity") +
  scale_fill_manual(values=c("red", "blue")) +
  xlab("Universities") +
  ylab("No. Publications") +
  ggtitle("Articles by Institutional Affiliation")

p1 + facet_grid(. ~ Category)

## Fig. 2
library(ineq)

#create smoothing vector for quantiles
vec<-sort(seq(0,1,by = 1/nrow(phd.rank)), decreasing = T)
vec<-vec[1:(length(vec)-1)]
vec2<-sort(seq(0,1,by = 1/nrow(author.rank)), decreasing = T)
vec2<-vec2[1:(length(vec2)-1)]
#create quantile means
phd.rank$quant <- cut(phd.rank$Freq+vec, breaks=quantile(phd.rank$Freq+vec, probs=seq(0,1, by=0.05), na.rm=TRUE), include.lowest=TRUE, labels = seq(1:20))
phd.mean<-sort(unname(tapply(phd.rank$Freq, phd.rank$quant, mean)), decreasing = F)
author.rank$quant <- cut(author.rank$Freq+vec2, breaks=quantile(author.rank$Freq+vec2, probs=seq(0,1, by=0.05), na.rm=TRUE), include.lowest=TRUE, labels = seq(1:20))
author.mean<-sort(unname(tapply(author.rank$Freq, author.rank$quant, mean)), decreasing = F)
#create Lorenz objects
Distr1 <- Lc(phd.mean, n = rep(1,length(phd.mean)), plot =F)
Distr2 <- Lc(author.mean, n = rep(1,length(author.mean)), plot =F)

lor1<-data.frame(1-Distr1$p, 1-Distr1$L, c("PhD"))
lor2<-data.frame(1-Distr2$p, 1-Distr2$L, c("Author"))
colnames(lor1)<-c("x", "y", "category")
colnames(lor2)<-c("x", "y", "category")
lor.all<-rbind(lor1, lor2)

#plot BW
ggplot(lor.all, aes(x=x, y=y, shape=category, linetype=category)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_point(size=2) +
  geom_line() +
  scale_shape_manual(values=c(17,5)) +
  geom_abline(intercept = 0, slope = 1) +
  annotate("text", x = .5, y = .5, angle=atan(.75)*180/pi, vjust=1.5, label = "Equality") +
  xlab("Fraction of Institutions") +
  ylab("Fraction of Articles Published") +
  ggtitle("Inequality in Academic Publishing, 1970-2015")

#Color
ggplot(lor.all, aes(x=x, y=y, shape=category, linetype=category, color=category)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_point(size=2) +
  geom_line() +
  scale_shape_manual(values=c(17,5)) +
  scale_colour_manual(values=c("red", "blue")) +
  geom_abline(intercept = 0, slope = 1) +
  annotate("text", x = .5, y = .5, angle=atan(.75)*180/pi, vjust=1.5, label = "Equality") +
  xlab("Fraction of Institutions") +
  ylab("Fraction of Articles Published") +
  ggtitle("Inequality in Academic Publishing, 1970-2015")


## Fig. 3
all1<-data.frame(het2.df[,1:3], c("Author"))
all1<-all1[,-3]
all2<-data.frame(het2.df[,-2], c("PhD"))
remove<-c(3,4,5,6)
all2<-all2[,-remove]
colnames(all1)<-c("Journal", "Heterogeneity", "Category")
colnames(all2)<-c("Journal", "Heterogeneity", "Category")
all3<-rbind(all1, all2)

#reoroder factors by variable
#plot BW
ggplot(all3, aes(reorder(factor(Journal), -Heterogeneity), Heterogeneity)) + #boxplot with ordered factors
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_boxplot(aes(fill = Category)) +
  scale_fill_manual(values = c("grey50","white")) +
  xlab("Journals")+
  ylab("Heterogneity Score")+
  ggtitle("Institutional Heterogeneity Across 4 Journals, 1970-2015")

#Color
ggplot(all3, aes(reorder(factor(Journal), -Heterogeneity), Heterogeneity)) + #boxplot with ordered factors
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_boxplot(aes(fill = Category)) +
  scale_fill_manual(values = c("blue","red")) +
  xlab("Journals")+
  ylab("Heterogneity Score")+
  ggtitle("Institutional Heterogeneity Across 4 Journals, 1970-2015")

## Fig. 4 Heterogeneity Over Time ##
#transform het.yearly table into plot table
d1<-data.frame(het.yearly$year, het.yearly$het.score.author, c("author"))
d2<-data.frame(het.yearly$year, (het.yearly$het.score.phd), c("phd"))
colnames(d1)<-c("year", "score", "measure")
colnames(d2)<-c("year", "score", "measure")
het.time<-rbind(d1, d2)

#plot BW
ggplot(het.time, aes(x=year, y=score, shape=measure, linetype=measure)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_point(size=2) +
  scale_shape_manual(values=c(17,1)) +
  xlab("Year") +
  ylab("Heterogeneity") +
  ggtitle("Institutional Heterogeneity Over Time, 1970-2015") +
  stat_smooth(method=loess, color="black")

#Color
colnames(het.time)[3]<-c("category")
ggplot(het.time, aes(x=year, y=score, shape=category, linetype=category, color=category)) +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_point(size=2) +
  scale_shape_manual(values=c(17,1)) +
  scale_colour_manual(values=c("red", "blue")) +
  xlab("Year") +
  ylab("Heterogeneity") +
  ggtitle("Institutional Heterogeneity Over Time, 1970-2015") +
  #stat_smooth(method=loess)
  stat_smooth(method="lm", formula=y ~ poly(x, 2))

#no. journals per year
plot(het.yearly$year, het.yearly$no.articles)

### Fig. 5 Gender ###

#plot BW
#creat 4-part faceted graph
p5 <- ggplot(gender.df, aes(year, gend.score*100)) + geom_point() +
  #scale_shape_manual(values=c(17,1,3,5)) +
  theme(plot.title = element_text(hjust = 0.5), legend.position="none") +
  geom_hline(yintercept=50, linetype=2) +
  xlab("Year") +
  ylab("% of Articles by Women") +
  ylim(0,100) +
  ggtitle("Gender in Academic Publishing") +
  stat_smooth(method=loess, color="black")

# With one variable
p5 + facet_grid(. ~journal) 

#Color
#creat 4-part faceted graph
p5 <- ggplot(gender.df, aes(year, gend.score*100, color=journal)) + geom_point() +
  theme(plot.title = element_text(hjust = 0.5), legend.position="none") +
  geom_hline(yintercept=50, linetype=2) +
  xlab("Year") +
  ylab("% of Articles by Women") +
  ylim(0,100) +
  ggtitle("Gender in Academic Publishing") +
  stat_smooth(method=loess)

# With one variable
p5 + facet_grid(. ~journal) 







